﻿<#
There is a bug in TFS2018.0 that causes the installer to generate a 
self-signed SSL certificate that Git using OpenSSL simply hates. 
This bug is supposed to be fixed as part of TFS2018.1.

This script generates a new self-signed SSL certificate for TFS2018 
and installs it into IIS.  

Run this on the TFS2018 application tier machine.  

Getting this fix was a team effort. Huge thanks to the following 
people at Microsoft for getting this knocked out: Johannes 
Schindelin, Ed Thomson, J Wyman, Philip Kelley, and Aaron Hallberg. 
Extra big thanks to Grant Holliday for the New-SelfSignedCertificate logic!
#>

# Generate a new self-signed certificate 
$cert = New-SelfSignedCertificate -DnsName ${Env:ComputerName}${Env:UserDnsDomain},${ENV:ComputerName}  `
-CertStoreLocation "cert:\LocalMachine\My" `
-KeyUsage DigitalSignature, KeyEncipherment, DataEncipherment, CertSign `
-NotAfter (Get-Date).AddYears(7) `
-FriendlyName "TFS Self-Signed SSL (${Env:ComputerName}${Env:UserDnsDomain},${ENV:ComputerName})"
 
# Output the thumbprint
# $cert.Thumbprint

 
# Output the Base64-encoded public key for Git clients to add to their .gitconfig/sslCAInfo/ca-bundle.crt
# "-----BEGIN CERTIFICATE-----`r`n" + [Convert]::ToBase64String(($cert).RawData, 'InsertLineBreaks') + "`r`n-----END CERTIFICATE-----`r`n"
 
# Move the certificate to the WebHosting store so that IIS can use it
$cert | Move-Item -Destination Cert:\LocalMachine\WebHosting\
 
# From Ben Day --> Rebind IIS to new cert
$bindings = Get-WebBinding -Protocol https

$bindingNumber = 1

foreach($binding in $bindings)
{
    Write-Output "binding $bindingNumber protocol`: $($binding.protocol)"
    Write-Output "binding $bindingNumber binding information`: $($binding.bindingInformation)"
    Write-Output "binding $bindingNumber sslFlags`: $($binding.sslFlags)"
    Write-Output "binding $bindingNumber certificateHash`: $($binding.certificateHash)"
    Write-Output "binding $bindingNumber certificateStoreName`: $($binding.certificateStoreName)"
    
    Write-Output "binding $bindingNumber --> Rebinding to new certificate..."
    $binding.RebindSslCertificate($cert.Thumbprint, "WebHosting")
    Write-Output "binding $bindingNumber --> Rebinding to new certificate complete."
        
    $bindingNumber++
}