﻿<#
This script exports the new self-signed SSL certificate that was 
generated for TFS2018. This script assumes that TFS is the only 
IIS application on this machine with https enabled. This script 
outputs the SSL certificate in two formats to two different files:

1) exported-from-tfs.cer: this is the CER formatted certificate 
that will be used in script #3 and imported to the user's trusted
root certificates

2) exported-from-tfs-for-gitconfig.txt: this formats the certificate
that that it can be added to Git's ca-bundle.crt file by script #4

Run this on the TFS2018 application tier machine.  

Benjamin Day
https://www.benday.com
benday@benday.com
#>

$binding = Get-WebBinding -Protocol https | Select -First 1

<#
Write-Output "binding protocol`: $($binding.protocol)"
Write-Output "binding binding information`: $($binding.bindingInformation)"
Write-Output "binding sslFlags`: $($binding.sslFlags)"
Write-Output "binding certificateHash`: $($binding.certificateHash)"
Write-Output "binding certificateStoreName`: $($binding.certificateStoreName)"
Write-Output ""    
#>

$thumbprint = $binding.certificateHash

$selectedcert = (Get-ChildItem –Path cert:\LocalMachine\WebHosting\$thumbprint)

$certFilePath = "$PSScriptRoot\exported-from-tfs.cer"

Export-Certificate -Cert $selectedcert -FilePath $certFilePath

$certRawData = $selectedcert.RawData

$certRawDataConverted = [Convert]::ToBase64String($certRawData, 'InsertLineBreaks')

$builder = new-object -TypeName System.Text.StringBuilder

[void]$builder.AppendLine()
[void]$builder.AppendLine("# $($binding.bindingInformation)")
[void]$builder.AppendLine("# $($binding.certificateHash)")

[void]$builder.AppendLine("-----BEGIN CERTIFICATE-----")
[void]$builder.AppendLine($certRawDataConverted)
[void]$builder.AppendLine("-----END CERTIFICATE-----")
[void]$builder.AppendLine()

$certFilePathForGitConfig = "$PSScriptRoot\exported-from-tfs-for-gitconfig.txt"

$builder.ToString() | Out-File $certFilePathForGitConfig 
